/*******************************************************************************
* File Name: buttons.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "buttons.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 buttons__PORT == 15 && ((buttons__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: buttons_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void buttons_Write(uint8 value) 
{
    uint8 staticBits = (buttons_DR & (uint8)(~buttons_MASK));
    buttons_DR = staticBits | ((uint8)(value << buttons_SHIFT) & buttons_MASK);
}


/*******************************************************************************
* Function Name: buttons_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  buttons_DM_STRONG     Strong Drive 
*  buttons_DM_OD_HI      Open Drain, Drives High 
*  buttons_DM_OD_LO      Open Drain, Drives Low 
*  buttons_DM_RES_UP     Resistive Pull Up 
*  buttons_DM_RES_DWN    Resistive Pull Down 
*  buttons_DM_RES_UPDWN  Resistive Pull Up/Down 
*  buttons_DM_DIG_HIZ    High Impedance Digital 
*  buttons_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void buttons_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(buttons_0, mode);
	CyPins_SetPinDriveMode(buttons_1, mode);
	CyPins_SetPinDriveMode(buttons_2, mode);
	CyPins_SetPinDriveMode(buttons_3, mode);
	CyPins_SetPinDriveMode(buttons_4, mode);
	CyPins_SetPinDriveMode(buttons_5, mode);
	CyPins_SetPinDriveMode(buttons_6, mode);
	CyPins_SetPinDriveMode(buttons_7, mode);
}


/*******************************************************************************
* Function Name: buttons_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro buttons_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 buttons_Read(void) 
{
    return (buttons_PS & buttons_MASK) >> buttons_SHIFT;
}


/*******************************************************************************
* Function Name: buttons_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 buttons_ReadDataReg(void) 
{
    return (buttons_DR & buttons_MASK) >> buttons_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(buttons_INTSTAT) 

    /*******************************************************************************
    * Function Name: buttons_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 buttons_ClearInterrupt(void) 
    {
        return (buttons_INTSTAT & buttons_MASK) >> buttons_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
