/*******************************************************************************
* File Name: led_button5_1_PM.c
* Version 3.20
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "led_button5_1.h"

static led_button5_1_backupStruct led_button5_1_backup;


/*******************************************************************************
* Function Name: led_button5_1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_button5_1_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void led_button5_1_SaveConfig(void) 
{

    #if(!led_button5_1_UsingFixedFunction)
        #if(!led_button5_1_PWMModeIsCenterAligned)
            led_button5_1_backup.PWMPeriod = led_button5_1_ReadPeriod();
        #endif /* (!led_button5_1_PWMModeIsCenterAligned) */
        led_button5_1_backup.PWMUdb = led_button5_1_ReadCounter();
        #if (led_button5_1_UseStatus)
            led_button5_1_backup.InterruptMaskValue = led_button5_1_STATUS_MASK;
        #endif /* (led_button5_1_UseStatus) */

        #if(led_button5_1_DeadBandMode == led_button5_1__B_PWM__DBM_256_CLOCKS || \
            led_button5_1_DeadBandMode == led_button5_1__B_PWM__DBM_2_4_CLOCKS)
            led_button5_1_backup.PWMdeadBandValue = led_button5_1_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(led_button5_1_KillModeMinTime)
             led_button5_1_backup.PWMKillCounterPeriod = led_button5_1_ReadKillTime();
        #endif /* (led_button5_1_KillModeMinTime) */

        #if(led_button5_1_UseControl)
            led_button5_1_backup.PWMControlRegister = led_button5_1_ReadControlRegister();
        #endif /* (led_button5_1_UseControl) */
    #endif  /* (!led_button5_1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: led_button5_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_button5_1_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void led_button5_1_RestoreConfig(void) 
{
        #if(!led_button5_1_UsingFixedFunction)
            #if(!led_button5_1_PWMModeIsCenterAligned)
                led_button5_1_WritePeriod(led_button5_1_backup.PWMPeriod);
            #endif /* (!led_button5_1_PWMModeIsCenterAligned) */

            led_button5_1_WriteCounter(led_button5_1_backup.PWMUdb);

            #if (led_button5_1_UseStatus)
                led_button5_1_STATUS_MASK = led_button5_1_backup.InterruptMaskValue;
            #endif /* (led_button5_1_UseStatus) */

            #if(led_button5_1_DeadBandMode == led_button5_1__B_PWM__DBM_256_CLOCKS || \
                led_button5_1_DeadBandMode == led_button5_1__B_PWM__DBM_2_4_CLOCKS)
                led_button5_1_WriteDeadTime(led_button5_1_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(led_button5_1_KillModeMinTime)
                led_button5_1_WriteKillTime(led_button5_1_backup.PWMKillCounterPeriod);
            #endif /* (led_button5_1_KillModeMinTime) */

            #if(led_button5_1_UseControl)
                led_button5_1_WriteControlRegister(led_button5_1_backup.PWMControlRegister);
            #endif /* (led_button5_1_UseControl) */
        #endif  /* (!led_button5_1_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: led_button5_1_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_button5_1_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void led_button5_1_Sleep(void) 
{
    #if(led_button5_1_UseControl)
        if(led_button5_1_CTRL_ENABLE == (led_button5_1_CONTROL & led_button5_1_CTRL_ENABLE))
        {
            /*Component is enabled */
            led_button5_1_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            led_button5_1_backup.PWMEnableState = 0u;
        }
    #endif /* (led_button5_1_UseControl) */

    /* Stop component */
    led_button5_1_Stop();

    /* Save registers configuration */
    led_button5_1_SaveConfig();
}


/*******************************************************************************
* Function Name: led_button5_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_button5_1_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void led_button5_1_Wakeup(void) 
{
     /* Restore registers values */
    led_button5_1_RestoreConfig();

    if(led_button5_1_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        led_button5_1_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
