/*******************************************************************************
* File Name: led_knob1_2_PM.c
* Version 3.20
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "led_knob1_2.h"

static led_knob1_2_backupStruct led_knob1_2_backup;


/*******************************************************************************
* Function Name: led_knob1_2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_knob1_2_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void led_knob1_2_SaveConfig(void) 
{

    #if(!led_knob1_2_UsingFixedFunction)
        #if(!led_knob1_2_PWMModeIsCenterAligned)
            led_knob1_2_backup.PWMPeriod = led_knob1_2_ReadPeriod();
        #endif /* (!led_knob1_2_PWMModeIsCenterAligned) */
        led_knob1_2_backup.PWMUdb = led_knob1_2_ReadCounter();
        #if (led_knob1_2_UseStatus)
            led_knob1_2_backup.InterruptMaskValue = led_knob1_2_STATUS_MASK;
        #endif /* (led_knob1_2_UseStatus) */

        #if(led_knob1_2_DeadBandMode == led_knob1_2__B_PWM__DBM_256_CLOCKS || \
            led_knob1_2_DeadBandMode == led_knob1_2__B_PWM__DBM_2_4_CLOCKS)
            led_knob1_2_backup.PWMdeadBandValue = led_knob1_2_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(led_knob1_2_KillModeMinTime)
             led_knob1_2_backup.PWMKillCounterPeriod = led_knob1_2_ReadKillTime();
        #endif /* (led_knob1_2_KillModeMinTime) */

        #if(led_knob1_2_UseControl)
            led_knob1_2_backup.PWMControlRegister = led_knob1_2_ReadControlRegister();
        #endif /* (led_knob1_2_UseControl) */
    #endif  /* (!led_knob1_2_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: led_knob1_2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_knob1_2_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void led_knob1_2_RestoreConfig(void) 
{
        #if(!led_knob1_2_UsingFixedFunction)
            #if(!led_knob1_2_PWMModeIsCenterAligned)
                led_knob1_2_WritePeriod(led_knob1_2_backup.PWMPeriod);
            #endif /* (!led_knob1_2_PWMModeIsCenterAligned) */

            led_knob1_2_WriteCounter(led_knob1_2_backup.PWMUdb);

            #if (led_knob1_2_UseStatus)
                led_knob1_2_STATUS_MASK = led_knob1_2_backup.InterruptMaskValue;
            #endif /* (led_knob1_2_UseStatus) */

            #if(led_knob1_2_DeadBandMode == led_knob1_2__B_PWM__DBM_256_CLOCKS || \
                led_knob1_2_DeadBandMode == led_knob1_2__B_PWM__DBM_2_4_CLOCKS)
                led_knob1_2_WriteDeadTime(led_knob1_2_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(led_knob1_2_KillModeMinTime)
                led_knob1_2_WriteKillTime(led_knob1_2_backup.PWMKillCounterPeriod);
            #endif /* (led_knob1_2_KillModeMinTime) */

            #if(led_knob1_2_UseControl)
                led_knob1_2_WriteControlRegister(led_knob1_2_backup.PWMControlRegister);
            #endif /* (led_knob1_2_UseControl) */
        #endif  /* (!led_knob1_2_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: led_knob1_2_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_knob1_2_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void led_knob1_2_Sleep(void) 
{
    #if(led_knob1_2_UseControl)
        if(led_knob1_2_CTRL_ENABLE == (led_knob1_2_CONTROL & led_knob1_2_CTRL_ENABLE))
        {
            /*Component is enabled */
            led_knob1_2_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            led_knob1_2_backup.PWMEnableState = 0u;
        }
    #endif /* (led_knob1_2_UseControl) */

    /* Stop component */
    led_knob1_2_Stop();

    /* Save registers configuration */
    led_knob1_2_SaveConfig();
}


/*******************************************************************************
* Function Name: led_knob1_2_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  led_knob1_2_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void led_knob1_2_Wakeup(void) 
{
     /* Restore registers values */
    led_knob1_2_RestoreConfig();

    if(led_knob1_2_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        led_knob1_2_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
