/*******************************************************************************
* File Name: led_knob5_6.h
* Version 3.20
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_led_knob5_6_H)
#define CY_PWM_led_knob5_6_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 led_knob5_6_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define led_knob5_6_Resolution                     (8u)
#define led_knob5_6_UsingFixedFunction             (0u)
#define led_knob5_6_DeadBandMode                   (0u)
#define led_knob5_6_KillModeMinTime                (0u)
#define led_knob5_6_KillMode                       (0u)
#define led_knob5_6_PWMMode                        (1u)
#define led_knob5_6_PWMModeIsCenterAligned         (0u)
#define led_knob5_6_DeadBandUsed                   (0u)
#define led_knob5_6_DeadBand2_4                    (0u)

#if !defined(led_knob5_6_PWMUDB_genblk8_stsreg__REMOVED)
    #define led_knob5_6_UseStatus                  (1u)
#else
    #define led_knob5_6_UseStatus                  (0u)
#endif /* !defined(led_knob5_6_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(led_knob5_6_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define led_knob5_6_UseControl                 (1u)
#else
    #define led_knob5_6_UseControl                 (0u)
#endif /* !defined(led_knob5_6_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define led_knob5_6_UseOneCompareMode              (0u)
#define led_knob5_6_MinimumKillTime                (1u)
#define led_knob5_6_EnableMode                     (0u)

#define led_knob5_6_CompareMode1SW                 (0u)
#define led_knob5_6_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_20 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define led_knob5_6__B_PWM__DISABLED 0
#define led_knob5_6__B_PWM__ASYNCHRONOUS 1
#define led_knob5_6__B_PWM__SINGLECYCLE 2
#define led_knob5_6__B_PWM__LATCHED 3
#define led_knob5_6__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define led_knob5_6__B_PWM__DBMDISABLED 0
#define led_knob5_6__B_PWM__DBM_2_4_CLOCKS 1
#define led_knob5_6__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define led_knob5_6__B_PWM__ONE_OUTPUT 0
#define led_knob5_6__B_PWM__TWO_OUTPUTS 1
#define led_knob5_6__B_PWM__DUAL_EDGE 2
#define led_knob5_6__B_PWM__CENTER_ALIGN 3
#define led_knob5_6__B_PWM__DITHER 5
#define led_knob5_6__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define led_knob5_6__B_PWM__LESS_THAN 1
#define led_knob5_6__B_PWM__LESS_THAN_OR_EQUAL 2
#define led_knob5_6__B_PWM__GREATER_THAN 3
#define led_knob5_6__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define led_knob5_6__B_PWM__EQUAL 0
#define led_knob5_6__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!led_knob5_6_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!led_knob5_6_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!led_knob5_6_PWMModeIsCenterAligned) */
        #if (led_knob5_6_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (led_knob5_6_UseStatus) */

        /* Backup for Deadband parameters */
        #if(led_knob5_6_DeadBandMode == led_knob5_6__B_PWM__DBM_256_CLOCKS || \
            led_knob5_6_DeadBandMode == led_knob5_6__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(led_knob5_6_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (led_knob5_6_KillModeMinTime) */

        /* Backup control register */
        #if(led_knob5_6_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (led_knob5_6_UseControl) */

    #endif /* (!led_knob5_6_UsingFixedFunction) */

}led_knob5_6_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    led_knob5_6_Start(void) ;
void    led_knob5_6_Stop(void) ;

#if (led_knob5_6_UseStatus || led_knob5_6_UsingFixedFunction)
    void  led_knob5_6_SetInterruptMode(uint8 interruptMode) ;
    uint8 led_knob5_6_ReadStatusRegister(void) ;
#endif /* (led_knob5_6_UseStatus || led_knob5_6_UsingFixedFunction) */

#define led_knob5_6_GetInterruptSource() led_knob5_6_ReadStatusRegister()

#if (led_knob5_6_UseControl)
    uint8 led_knob5_6_ReadControlRegister(void) ;
    void  led_knob5_6_WriteControlRegister(uint8 control)
          ;
#endif /* (led_knob5_6_UseControl) */

#if (led_knob5_6_UseOneCompareMode)
   #if (led_knob5_6_CompareMode1SW)
       void    led_knob5_6_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (led_knob5_6_CompareMode1SW) */
#else
    #if (led_knob5_6_CompareMode1SW)
        void    led_knob5_6_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (led_knob5_6_CompareMode1SW) */
    #if (led_knob5_6_CompareMode2SW)
        void    led_knob5_6_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (led_knob5_6_CompareMode2SW) */
#endif /* (led_knob5_6_UseOneCompareMode) */

#if (!led_knob5_6_UsingFixedFunction)
    uint8   led_knob5_6_ReadCounter(void) ;
    uint8 led_knob5_6_ReadCapture(void) ;

    #if (led_knob5_6_UseStatus)
            void led_knob5_6_ClearFIFO(void) ;
    #endif /* (led_knob5_6_UseStatus) */

    void    led_knob5_6_WriteCounter(uint8 counter)
            ;
#endif /* (!led_knob5_6_UsingFixedFunction) */

void    led_knob5_6_WritePeriod(uint8 period)
        ;
uint8 led_knob5_6_ReadPeriod(void) ;

#if (led_knob5_6_UseOneCompareMode)
    void    led_knob5_6_WriteCompare(uint8 compare)
            ;
    uint8 led_knob5_6_ReadCompare(void) ;
#else
    void    led_knob5_6_WriteCompare1(uint8 compare)
            ;
    uint8 led_knob5_6_ReadCompare1(void) ;
    void    led_knob5_6_WriteCompare2(uint8 compare)
            ;
    uint8 led_knob5_6_ReadCompare2(void) ;
#endif /* (led_knob5_6_UseOneCompareMode) */


#if (led_knob5_6_DeadBandUsed)
    void    led_knob5_6_WriteDeadTime(uint8 deadtime) ;
    uint8   led_knob5_6_ReadDeadTime(void) ;
#endif /* (led_knob5_6_DeadBandUsed) */

#if ( led_knob5_6_KillModeMinTime)
    void led_knob5_6_WriteKillTime(uint8 killtime) ;
    uint8 led_knob5_6_ReadKillTime(void) ;
#endif /* ( led_knob5_6_KillModeMinTime) */

void led_knob5_6_Init(void) ;
void led_knob5_6_Enable(void) ;
void led_knob5_6_Sleep(void) ;
void led_knob5_6_Wakeup(void) ;
void led_knob5_6_SaveConfig(void) ;
void led_knob5_6_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define led_knob5_6_INIT_PERIOD_VALUE          (255u)
#define led_knob5_6_INIT_COMPARE_VALUE1        (255u)
#define led_knob5_6_INIT_COMPARE_VALUE2        (255u)
#define led_knob5_6_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    led_knob5_6_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    led_knob5_6_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    led_knob5_6_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    led_knob5_6_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define led_knob5_6_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  led_knob5_6_CTRL_CMPMODE2_SHIFT)
#define led_knob5_6_DEFAULT_COMPARE1_MODE      (uint8)((uint8)1u <<  led_knob5_6_CTRL_CMPMODE1_SHIFT)
#define led_knob5_6_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (led_knob5_6_UsingFixedFunction)
   #define led_knob5_6_PERIOD_LSB              (*(reg16 *) led_knob5_6_PWMHW__PER0)
   #define led_knob5_6_PERIOD_LSB_PTR          ( (reg16 *) led_knob5_6_PWMHW__PER0)
   #define led_knob5_6_COMPARE1_LSB            (*(reg16 *) led_knob5_6_PWMHW__CNT_CMP0)
   #define led_knob5_6_COMPARE1_LSB_PTR        ( (reg16 *) led_knob5_6_PWMHW__CNT_CMP0)
   #define led_knob5_6_COMPARE2_LSB            (0x00u)
   #define led_knob5_6_COMPARE2_LSB_PTR        (0x00u)
   #define led_knob5_6_COUNTER_LSB             (*(reg16 *) led_knob5_6_PWMHW__CNT_CMP0)
   #define led_knob5_6_COUNTER_LSB_PTR         ( (reg16 *) led_knob5_6_PWMHW__CNT_CMP0)
   #define led_knob5_6_CAPTURE_LSB             (*(reg16 *) led_knob5_6_PWMHW__CAP0)
   #define led_knob5_6_CAPTURE_LSB_PTR         ( (reg16 *) led_knob5_6_PWMHW__CAP0)
   #define led_knob5_6_RT1                     (*(reg8 *)  led_knob5_6_PWMHW__RT1)
   #define led_knob5_6_RT1_PTR                 ( (reg8 *)  led_knob5_6_PWMHW__RT1)

#else
   #if (led_knob5_6_Resolution == 8u) /* 8bit - PWM */

       #if(led_knob5_6_PWMModeIsCenterAligned)
           #define led_knob5_6_PERIOD_LSB      (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define led_knob5_6_PERIOD_LSB_PTR  ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define led_knob5_6_PERIOD_LSB      (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define led_knob5_6_PERIOD_LSB_PTR  ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (led_knob5_6_PWMModeIsCenterAligned) */

       #define led_knob5_6_COMPARE1_LSB        (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define led_knob5_6_COMPARE1_LSB_PTR    ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define led_knob5_6_COMPARE2_LSB        (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define led_knob5_6_COMPARE2_LSB_PTR    ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define led_knob5_6_COUNTERCAP_LSB      (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define led_knob5_6_COUNTERCAP_LSB_PTR  ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define led_knob5_6_COUNTER_LSB         (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define led_knob5_6_COUNTER_LSB_PTR     ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define led_knob5_6_CAPTURE_LSB         (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define led_knob5_6_CAPTURE_LSB_PTR     ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(led_knob5_6_PWMModeIsCenterAligned)
               #define led_knob5_6_PERIOD_LSB      (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define led_knob5_6_PERIOD_LSB_PTR  ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define led_knob5_6_PERIOD_LSB      (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define led_knob5_6_PERIOD_LSB_PTR  ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (led_knob5_6_PWMModeIsCenterAligned) */

            #define led_knob5_6_COMPARE1_LSB       (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define led_knob5_6_COMPARE1_LSB_PTR   ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define led_knob5_6_COMPARE2_LSB       (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define led_knob5_6_COMPARE2_LSB_PTR   ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define led_knob5_6_COUNTERCAP_LSB     (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define led_knob5_6_COUNTERCAP_LSB_PTR ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define led_knob5_6_COUNTER_LSB        (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define led_knob5_6_COUNTER_LSB_PTR    ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define led_knob5_6_CAPTURE_LSB        (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define led_knob5_6_CAPTURE_LSB_PTR    ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(led_knob5_6_PWMModeIsCenterAligned)
               #define led_knob5_6_PERIOD_LSB      (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define led_knob5_6_PERIOD_LSB_PTR  ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define led_knob5_6_PERIOD_LSB      (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define led_knob5_6_PERIOD_LSB_PTR  ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (led_knob5_6_PWMModeIsCenterAligned) */

            #define led_knob5_6_COMPARE1_LSB       (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define led_knob5_6_COMPARE1_LSB_PTR   ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define led_knob5_6_COMPARE2_LSB       (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define led_knob5_6_COMPARE2_LSB_PTR   ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define led_knob5_6_COUNTERCAP_LSB     (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define led_knob5_6_COUNTERCAP_LSB_PTR ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define led_knob5_6_COUNTER_LSB        (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define led_knob5_6_COUNTER_LSB_PTR    ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define led_knob5_6_CAPTURE_LSB        (*(reg16 *) led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define led_knob5_6_CAPTURE_LSB_PTR    ((reg16 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define led_knob5_6_AUX_CONTROLDP1          (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define led_knob5_6_AUX_CONTROLDP1_PTR      ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (led_knob5_6_Resolution == 8) */

   #define led_knob5_6_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define led_knob5_6_AUX_CONTROLDP0          (*(reg8 *)  led_knob5_6_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define led_knob5_6_AUX_CONTROLDP0_PTR      ((reg8 *)   led_knob5_6_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (led_knob5_6_UsingFixedFunction) */

#if(led_knob5_6_KillModeMinTime )
    #define led_knob5_6_KILLMODEMINTIME        (*(reg8 *)  led_knob5_6_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define led_knob5_6_KILLMODEMINTIME_PTR    ((reg8 *)   led_knob5_6_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (led_knob5_6_KillModeMinTime ) */

#if(led_knob5_6_DeadBandMode == led_knob5_6__B_PWM__DBM_256_CLOCKS)
    #define led_knob5_6_DEADBAND_COUNT         (*(reg8 *)  led_knob5_6_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define led_knob5_6_DEADBAND_COUNT_PTR     ((reg8 *)   led_knob5_6_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define led_knob5_6_DEADBAND_LSB_PTR       ((reg8 *)   led_knob5_6_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define led_knob5_6_DEADBAND_LSB           (*(reg8 *)  led_knob5_6_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(led_knob5_6_DeadBandMode == led_knob5_6__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (led_knob5_6_UsingFixedFunction)
        #define led_knob5_6_DEADBAND_COUNT         (*(reg8 *)  led_knob5_6_PWMHW__CFG0)
        #define led_knob5_6_DEADBAND_COUNT_PTR     ((reg8 *)   led_knob5_6_PWMHW__CFG0)
        #define led_knob5_6_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << led_knob5_6_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define led_knob5_6_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define led_knob5_6_DEADBAND_COUNT         (*(reg8 *)  led_knob5_6_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define led_knob5_6_DEADBAND_COUNT_PTR     ((reg8 *)   led_knob5_6_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define led_knob5_6_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << led_knob5_6_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define led_knob5_6_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (led_knob5_6_UsingFixedFunction) */
#endif /* (led_knob5_6_DeadBandMode == led_knob5_6__B_PWM__DBM_256_CLOCKS) */



#if (led_knob5_6_UsingFixedFunction)
    #define led_knob5_6_STATUS                 (*(reg8 *) led_knob5_6_PWMHW__SR0)
    #define led_knob5_6_STATUS_PTR             ((reg8 *) led_knob5_6_PWMHW__SR0)
    #define led_knob5_6_STATUS_MASK            (*(reg8 *) led_knob5_6_PWMHW__SR0)
    #define led_knob5_6_STATUS_MASK_PTR        ((reg8 *) led_knob5_6_PWMHW__SR0)
    #define led_knob5_6_CONTROL                (*(reg8 *) led_knob5_6_PWMHW__CFG0)
    #define led_knob5_6_CONTROL_PTR            ((reg8 *) led_knob5_6_PWMHW__CFG0)
    #define led_knob5_6_CONTROL2               (*(reg8 *) led_knob5_6_PWMHW__CFG1)
    #define led_knob5_6_CONTROL3               (*(reg8 *) led_knob5_6_PWMHW__CFG2)
    #define led_knob5_6_GLOBAL_ENABLE          (*(reg8 *) led_knob5_6_PWMHW__PM_ACT_CFG)
    #define led_knob5_6_GLOBAL_ENABLE_PTR      ( (reg8 *) led_knob5_6_PWMHW__PM_ACT_CFG)
    #define led_knob5_6_GLOBAL_STBY_ENABLE     (*(reg8 *) led_knob5_6_PWMHW__PM_STBY_CFG)
    #define led_knob5_6_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) led_knob5_6_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define led_knob5_6_BLOCK_EN_MASK          (led_knob5_6_PWMHW__PM_ACT_MSK)
    #define led_knob5_6_BLOCK_STBY_EN_MASK     (led_knob5_6_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define led_knob5_6_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define led_knob5_6_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define led_knob5_6_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define led_knob5_6_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define led_knob5_6_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define led_knob5_6_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define led_knob5_6_CTRL_ENABLE            (uint8)((uint8)0x01u << led_knob5_6_CTRL_ENABLE_SHIFT)
    #define led_knob5_6_CTRL_RESET             (uint8)((uint8)0x01u << led_knob5_6_CTRL_RESET_SHIFT)
    #define led_knob5_6_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << led_knob5_6_CTRL_CMPMODE2_SHIFT)
    #define led_knob5_6_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << led_knob5_6_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define led_knob5_6_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define led_knob5_6_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << led_knob5_6_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define led_knob5_6_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define led_knob5_6_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define led_knob5_6_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define led_knob5_6_STATUS_TC_INT_EN_MASK_SHIFT            (led_knob5_6_STATUS_TC_SHIFT - 4u)
    #define led_knob5_6_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define led_knob5_6_STATUS_CMP1_INT_EN_MASK_SHIFT          (led_knob5_6_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define led_knob5_6_STATUS_TC              (uint8)((uint8)0x01u << led_knob5_6_STATUS_TC_SHIFT)
    #define led_knob5_6_STATUS_CMP1            (uint8)((uint8)0x01u << led_knob5_6_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define led_knob5_6_STATUS_TC_INT_EN_MASK              (uint8)((uint8)led_knob5_6_STATUS_TC >> 4u)
    #define led_knob5_6_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)led_knob5_6_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define led_knob5_6_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define led_knob5_6_RT1_MASK              (uint8)((uint8)0x03u << led_knob5_6_RT1_SHIFT)
    #define led_knob5_6_SYNC                  (uint8)((uint8)0x03u << led_knob5_6_RT1_SHIFT)
    #define led_knob5_6_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define led_knob5_6_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << led_knob5_6_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define led_knob5_6_SYNCDSI_EN            (uint8)((uint8)0x0Fu << led_knob5_6_SYNCDSI_SHIFT)


#else
    #define led_knob5_6_STATUS                (*(reg8 *)   led_knob5_6_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define led_knob5_6_STATUS_PTR            ((reg8 *)    led_knob5_6_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define led_knob5_6_STATUS_MASK           (*(reg8 *)   led_knob5_6_PWMUDB_genblk8_stsreg__MASK_REG)
    #define led_knob5_6_STATUS_MASK_PTR       ((reg8 *)    led_knob5_6_PWMUDB_genblk8_stsreg__MASK_REG)
    #define led_knob5_6_STATUS_AUX_CTRL       (*(reg8 *)   led_knob5_6_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define led_knob5_6_CONTROL               (*(reg8 *)   led_knob5_6_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define led_knob5_6_CONTROL_PTR           ((reg8 *)    led_knob5_6_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define led_knob5_6_CTRL_ENABLE_SHIFT      (0x07u)
    #define led_knob5_6_CTRL_RESET_SHIFT       (0x06u)
    #define led_knob5_6_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define led_knob5_6_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define led_knob5_6_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define led_knob5_6_CTRL_ENABLE            (uint8)((uint8)0x01u << led_knob5_6_CTRL_ENABLE_SHIFT)
    #define led_knob5_6_CTRL_RESET             (uint8)((uint8)0x01u << led_knob5_6_CTRL_RESET_SHIFT)
    #define led_knob5_6_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << led_knob5_6_CTRL_CMPMODE2_SHIFT)
    #define led_knob5_6_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << led_knob5_6_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define led_knob5_6_STATUS_KILL_SHIFT          (0x05u)
    #define led_knob5_6_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define led_knob5_6_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define led_knob5_6_STATUS_TC_SHIFT            (0x02u)
    #define led_knob5_6_STATUS_CMP2_SHIFT          (0x01u)
    #define led_knob5_6_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define led_knob5_6_STATUS_KILL_INT_EN_MASK_SHIFT          (led_knob5_6_STATUS_KILL_SHIFT)
    #define led_knob5_6_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (led_knob5_6_STATUS_FIFONEMPTY_SHIFT)
    #define led_knob5_6_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (led_knob5_6_STATUS_FIFOFULL_SHIFT)
    #define led_knob5_6_STATUS_TC_INT_EN_MASK_SHIFT            (led_knob5_6_STATUS_TC_SHIFT)
    #define led_knob5_6_STATUS_CMP2_INT_EN_MASK_SHIFT          (led_knob5_6_STATUS_CMP2_SHIFT)
    #define led_knob5_6_STATUS_CMP1_INT_EN_MASK_SHIFT          (led_knob5_6_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define led_knob5_6_STATUS_KILL            (uint8)((uint8)0x00u << led_knob5_6_STATUS_KILL_SHIFT )
    #define led_knob5_6_STATUS_FIFOFULL        (uint8)((uint8)0x01u << led_knob5_6_STATUS_FIFOFULL_SHIFT)
    #define led_knob5_6_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << led_knob5_6_STATUS_FIFONEMPTY_SHIFT)
    #define led_knob5_6_STATUS_TC              (uint8)((uint8)0x01u << led_knob5_6_STATUS_TC_SHIFT)
    #define led_knob5_6_STATUS_CMP2            (uint8)((uint8)0x01u << led_knob5_6_STATUS_CMP2_SHIFT)
    #define led_knob5_6_STATUS_CMP1            (uint8)((uint8)0x01u << led_knob5_6_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define led_knob5_6_STATUS_KILL_INT_EN_MASK            (led_knob5_6_STATUS_KILL)
    #define led_knob5_6_STATUS_FIFOFULL_INT_EN_MASK        (led_knob5_6_STATUS_FIFOFULL)
    #define led_knob5_6_STATUS_FIFONEMPTY_INT_EN_MASK      (led_knob5_6_STATUS_FIFONEMPTY)
    #define led_knob5_6_STATUS_TC_INT_EN_MASK              (led_knob5_6_STATUS_TC)
    #define led_knob5_6_STATUS_CMP2_INT_EN_MASK            (led_knob5_6_STATUS_CMP2)
    #define led_knob5_6_STATUS_CMP1_INT_EN_MASK            (led_knob5_6_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define led_knob5_6_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define led_knob5_6_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define led_knob5_6_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define led_knob5_6_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define led_knob5_6_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* led_knob5_6_UsingFixedFunction */

#endif  /* CY_PWM_led_knob5_6_H */


/* [] END OF FILE */
