/* ========================================
 *
 * BEER Temperature controller
 *
 * Some of the code in here is holdover from a different project - I'll point out the useful stuff
 *
 * Robert Barron - embeditelectronics.com
 * ========================================
*/
#include <project.h>
#include <stdio.h>
#include <stdbool.h>
#include <math.h>

/* ========================================*/
//this is the desired temp in C
#define desired_temp 10


// This is calibration data for the raw touch data to the screen coordinates
#define TS_MINX 150
#define TS_MINY 130
#define TS_MAXX 3800
#define TS_MAXY 4000
// Size of the color selection boxes and the paintbrush size for lcd screen
#define BOXSIZE 40
#define PENRADIUS 3
int oldcolor, currentcolor;
#define NORMAL_B 1
#define OFF_B 2
#define COOL_B 4
#define VIOLET_B 8
#define DIM_B 16
#define DEMO_B 32
#define DEMO_DISABLE 64

#define NORMAL 11
#define OFF 12
#define COOL 13
#define VIOLET 14
#define DIM 15
#define DEMO 16

#define R 0x01
#define G 0x02
#define B 0x03
#define A 0x04
#define V 0x05
#define LEVEL 0x06
#define SYNC 0x10

#define NUM_LED 5

#define TIME_TRIGGER 300

#define BITCNT(a) (a&1) + ((a>>1)&1) + ((a>>2)&1) + ((a>>3)&1) + ((a>>4)&1) + ((a>>5)&1) + ((a>>6)&1) + ((a>>7)&1)

uint8 current_pin = 1;
uint8 last_pin = 1;
int seconds_elasped = 0;
int encoder = 0;
int last_encoder = 0;
//toggle demo mode turning on after 5 minutes
bool demo_disabled = false;
bool trans_up = false; //transition between button states
bool trans_down = false;
bool first_trans = true;
//bool first_on = true;
int led_down_compare = 255;
int led_up_compare = 0;
int MODE_C = NORMAL;//start on normal mode
int MODE_L = 0;
int led_on[6];
bool first_on;

CY_ISR_PROTO(decodeEvent);
CY_ISR_PROTO(buttonIsr);

//function prototype for the function that gets called when the timer triggers
CY_ISR_PROTO(tickEvent);


long mapCoor(long x, long in_min, long in_max, long out_min, long out_max);
void tickEvent();
cystatus Status;
int16 temperature;
//int16 desired_temp;
char tweet[50];
char desired[50];

int main()
{
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    
    CyDelay(10);
    
    //start up our timer. when the timer triggers (5 minutes by default) we check the psoc temp
    Timer_1_Start();
    
    //this is the function that runs when the timer triggers
    tick_StartEx(tickEvent);
    
    //intitialize the screen. with black background and white text
    TFTSHIELD_1_Start();
    TFTSHIELD_1_FillScreen(BLACK);
    TFTSHIELD_1_SetCursor(0,0);
    TFTSHIELD_1_SetTextColor(WHITE);  
    TFTSHIELD_1_SetTextSize(7);
    TFTSHIELD_1_SetRotation(1);
    
    //relay_Write(1);
    
    //get our intial temp reading
    Status = DieTemp_1_GetTemp(&temperature);
    TFTSHIELD_1_Write('\r');//clear screen and reset text cursor
    
    //turn on fridge if over desired temp (default=55)
    if(temperature > desired_temp+1)
    {
        relay_Write(1);   
    }
    else
    {
        relay_Write(0);
    }
    //create our strings to be printed
    sprintf(tweet,"%i C\n",temperature);
    sprintf(desired,"Goal:%i C",desired_temp);
    
    //print temp in huge letters
    TFTSHIELD_1_Print(tweet);
    TFTSHIELD_1_Print(desired);
    
    
    CyGlobalIntEnable; /* Uncomment this line to enable global interrupts. */
    for(;;)
    { 
        /*CyDelay(200);
        //Reading the Die Temperature value
        Status = DieTemp_1_GetTemp(&temperature);
        
        sprintf(tweet,"%i C\n",temperature);
        sprintf(desired,"Goal:%i C",desired_temp);
    
        //print temp in huge letters
        TFTSHIELD_1_Print(tweet);
        TFTSHIELD_1_Print(desired);
        CyDelay(1000);
        TFTSHIELD_1_Write('\r');
        relay_Write(0); 
        CyDelay(5000);
        relay_Write(1);*/
    }
}



// 5 minutes elapsed, check temp
CY_ISR(tickEvent)
{
    /* Reading the Die Temperature value */
    Status = DieTemp_1_GetTemp(&temperature);
    TFTSHIELD_1_Write('\r');//clear screen and reset text cursor
    
    //turn on fridge if over desired temp (default=55)
    if(temperature > desired_temp)
    {
        relay_Write(1);   
    }
    else
    {
        relay_Write(0);
    }
    
    //create our strings to be printed
    sprintf(tweet,"%i C\n",temperature);
    sprintf(desired,"Goal:%i C",desired_temp);
    
    //print temp in huge letters
    TFTSHIELD_1_Print(tweet);
    TFTSHIELD_1_Print(desired);
    
}

long mapCoor(long x, long in_min, long in_max, long out_min, long out_max)
{
  return (x - in_min) * (out_max - out_min) / (in_max - in_min) + out_min;
}




/* [] END OF FILE */
